==> get_storage-1.0.0.tar.gz: lib/src/storage/io.dart <==
import 'dart:async';
import 'dart:convert';
import 'dart:io';
import 'package:path_provider/path_provider.dart';
import '../storage_interface.dart';

class StorageImpl implements StorageInterface {
  StorageImpl(this.fileName, [this.path]);

  final String path, fileName;

  StreamController<Map<String, dynamic>> storage =
      StreamController<Map<String, dynamic>>();

  Map<String, dynamic> _data = Map();

  @override
  Stream<Map<String, dynamic>> get stream => storage.stream;

  @override
  StreamSubscription<Map<String, dynamic>> listen(
          void onData(Map<String, dynamic> event),
          {Function onError,
          void onDone(),
          bool cancelOnError}) =>
      stream.listen(onData,
          onError: onError, onDone: onDone, cancelOnError: cancelOnError);

  @override
  Future<void> clear() async {
    File _file = await _getFile();
    _data.clear();
    storage.add(null);
    return _file.deleteSync();
  }

  @override
  void dispose() {
    storage.close();
  }

  @override
  Future<bool> exists() async {
    File _file = await _getFile();
    return _file.existsSync();
  }

  @override
  Future<void> flush() async {
    final serialized = json.encode(_data);
    File _file = await _getFile();
    await _file.writeAsString(serialized, flush: true);
    return;
  }

  @override
  dynamic read(String key) {
    return _data[key];
  }

  @override
  Future<void> init([Map<String, dynamic> initialData]) async {
    _data = initialData ?? {};
    File _file = await _getFile();
    if (_file.existsSync()) {
      return _readFile();
    } else {
      return _writeFile(_data);
    }
  }

  @override
  Future<void> remove(String key) async {
    _data.remove(key);
    await _writeFile(_data);
  }

  @override
  Future<void> write(String key, dynamic value) async {
    _data[key] = value;
    await _writeFile(_data);
  }

  Future<void> _writeFile(Map<String, dynamic> data) async {
    _data = data;
    storage.add(data);
    File _file = await _getFile();
    _file.writeAsString(json.encode(data), flush: true);
  }

  Future<void> _readFile() async {
    File _file = await _getFile();

    final content = await _file.readAsString();
    _data = json.decode(content) as Map<String, dynamic>;
    storage.add(_data);
  }

  Future<File> _getFile() async {
    final dir = await _getDocumentDir();
    final _path = path ?? dir.path;
    final _file = File('$_path/$fileName');
    return _file;
  }

  Future<Directory> _getDocumentDir() async {
    try {
      return await getApplicationDocumentsDirectory();
    } catch (err) {
      throw err;
    }
  }
}

==> get_storage-1.0.2.tar.gz: lib/src/storage/io.dart <==
import 'dart:async';
import 'dart:convert';
import 'dart:io';
import 'package:path_provider/path_provider.dart';
import '../storage_interface.dart';

class StorageImpl implements StorageInterface {
  StorageImpl(this.fileName, [this.path]);

  final String path, fileName;

  StreamController<Map<String, dynamic>> storage =
      StreamController<Map<String, dynamic>>();

  Map<String, dynamic> _data = Map();

  @override
  Stream<Map<String, dynamic>> get stream => storage.stream;

  @override
  StreamSubscription<Map<String, dynamic>> listen(
          void onData(Map<String, dynamic> event),
          {Function onError,
          void onDone(),
          bool cancelOnError}) =>
      stream.listen(onData,
          onError: onError, onDone: onDone, cancelOnError: cancelOnError);

  @override
  Future<void> clear() async {
    File _file = await _getFile();
    _data.clear();
    storage.add(null);
    return _file.deleteSync();
  }

  @override
  void dispose() {
    storage.close();
  }

  @override
  Future<bool> exists() async {
    File _file = await _getFile();
    return _file.existsSync();
  }

  @override
  Future<void> flush() async {
    final serialized = json.encode(_data);
    File _file = await _getFile();
    await _file.writeAsString(serialized, flush: true);
    return;
  }

  @override
  dynamic read(String key) {
    return _data[key];
  }

  @override
  Future<void> init([Map<String, dynamic> initialData]) async {
    _data = initialData ?? {};
    File _file = await _getFile();
    if (_file.existsSync()) {
      return _readFile();
    } else {
      return _writeFile(_data);
    }
  }

  @override
  Future<void> remove(String key) async {
    _data.remove(key);
    await _writeFile(_data);
  }

  @override
  Future<void> write(String key, dynamic value) async {
    _data[key] = value;
    await _writeFile(_data);
  }

  Future<void> _writeFile(Map<String, dynamic> data) async {
    _data = data;
    storage.add(data);
    File _file = await _getFile();
    _file.writeAsString(json.encode(data), flush: true);
  }

  Future<void> _readFile() async {
    File _file = await _getFile();

    final content = await _file.readAsString();
    _data = json?.decode(content) as Map<String, dynamic>;
    storage.add(_data);
  }

  Future<File> _getFile() async {
    final dir = await _getDocumentDir();
    final _path = path ?? dir.path;
    final _file = File('$_path/$fileName');
    return _file;
  }

  Future<Directory> _getDocumentDir() async {
    try {
      return await getApplicationDocumentsDirectory();
    } catch (err) {
      throw err;
    }
  }
}
